@@ -2,7 +2,6 @@ var searchData=
 [
   ['saxdocumentbuilder',['SAXDocumentBuilder',['../servicecom_1_1sun_1_1star_1_1xml_1_1dom_1_1SAXDocumentBuilder.html',1,'com::sun::star::xml::dom']]],
   ['saxdocumenthandler',['SaxDocumentHandler',['../servicecom_1_1sun_1_1star_1_1xml_1_1input_1_1SaxDocumentHandler.html',1,'com::sun::star::xml::input']]],
-  ['saxeventkeeper',['SAXEventKeeper',['../servicecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1SAXEventKeeper.html',1,'com::sun::star::xml::crypto::sax']]],
   ['saxexception',['SAXException',['../exceptioncom_1_1sun_1_1star_1_1xml_1_1sax_1_1SAXException.html',1,'com::sun::star::xml::sax']]],
   ['saxinvalidcharacterexception',['SAXInvalidCharacterException',['../exceptioncom_1_1sun_1_1star_1_1xml_1_1sax_1_1SAXInvalidCharacterException.html',1,'com::sun::star::xml::sax']]],
   ['saxparseexception',['SAXParseException',['../exceptioncom_1_1sun_1_1star_1_1xml_1_1sax_1_1SAXParseException.html',1,'com::sun::star::xml::sax']]],
@@ -81,13 +80,10 @@ var searchData=
   ['sheetrangesquery',['SheetRangesQuery',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SheetRangesQuery.html',1,'com::sun::star::sheet']]],
   ['sheetsortdescriptor',['SheetSortDescriptor',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor.html',1,'com::sun::star::sheet']]],
   ['sheetsortdescriptor2',['SheetSortDescriptor2',['../servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor2.html',1,'com::sun::star::sheet']]],
-  ['signaturecreator',['SignatureCreator',['../servicecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1SignatureCreator.html',1,'com::sun::star::xml::crypto::sax']]],
   ['signatureexception',['SignatureException',['../exceptioncom_1_1sun_1_1star_1_1security_1_1SignatureException.html',1,'com::sun::star::security']]],
-  ['signatureverifier',['SignatureVerifier',['../servicecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1SignatureVerifier.html',1,'com::sun::star::xml::crypto::sax']]],
   ['simplecommandmail',['SimpleCommandMail',['../servicecom_1_1sun_1_1star_1_1system_1_1SimpleCommandMail.html',1,'com::sun::star::system']]],
   ['simplefileaccess',['SimpleFileAccess',['../servicecom_1_1sun_1_1star_1_1ucb_1_1SimpleFileAccess.html',1,'com::sun::star::ucb']]],
   ['simplefontmetric',['SimpleFontMetric',['../structcom_1_1sun_1_1star_1_1awt_1_1SimpleFontMetric.html',1,'com::sun::star::awt']]],
-  ['simplelogring',['SimpleLogRing',['../servicecom_1_1sun_1_1star_1_1logging_1_1SimpleLogRing.html',1,'com::sun::star::logging']]],
   ['simpleregistry',['SimpleRegistry',['../servicecom_1_1sun_1_1star_1_1registry_1_1SimpleRegistry.html',1,'com::sun::star::registry']]],
   ['simplesetaccess',['SimpleSetAccess',['../servicecom_1_1sun_1_1star_1_1configuration_1_1SimpleSetAccess.html',1,'com::sun::star::configuration']]],
   ['simplesetupdate',['SimpleSetUpdate',['../servicecom_1_1sun_1_1star_1_1configuration_1_1SimpleSetUpdate.html',1,'com::sun::star::configuration']]],
@@ -144,7 +140,7 @@ var searchData=
   ['standarddiagramcreationparameters',['StandardDiagramCreationParameters',['../servicecom_1_1sun_1_1star_1_1chart2_1_1StandardDiagramCreationParameters.html',1,'com::sun::star::chart2']]],
   ['startmodule',['StartModule',['../servicecom_1_1sun_1_1star_1_1frame_1_1StartModule.html',1,'com::sun::star::frame']]],
   ['statechangeinprogressexception',['StateChangeInProgressException',['../exceptioncom_1_1sun_1_1star_1_1embed_1_1StateChangeInProgressException.html',1,'com::sun::star::embed']]],
-  ['statement',['Statement',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1Statement.html',1,'Statement'],['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1Statement.html',1,'Statement'],['../structcom_1_1sun_1_1star_1_1rdf_1_1Statement.html',1,'Statement']]],
+  ['statement',['Statement',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1Statement.html',1,'Statement'],['../servicecom_1_1sun_1_1star_1_1sdbc_1_1Statement.html',1,'Statement'],['../structcom_1_1sun_1_1star_1_1rdf_1_1Statement.html',1,'Statement']]],
   ['statusbarcontroller',['StatusbarController',['../servicecom_1_1sun_1_1star_1_1frame_1_1StatusbarController.html',1,'com::sun::star::frame']]],
   ['statusbarcontrollerfactory',['StatusbarControllerFactory',['../servicecom_1_1sun_1_1star_1_1frame_1_1StatusbarControllerFactory.html',1,'com::sun::star::frame']]],
   ['statusindicatorfactory',['StatusIndicatorFactory',['../servicecom_1_1sun_1_1star_1_1task_1_1StatusIndicatorFactory.html',1,'com::sun::star::task']]],
